@@ -8,6 +8,8 @@ from pydantic import Field, BaseModel
 from pymultirole_plugins.v1.processor import ProcessorParameters, ProcessorBase
 from pymultirole_plugins.v1.schema import Document, AltText
 
+from .fakerop import FakerOp
+
 OPERATOR_EXAMPLE1 = {
     "type": "mask",
     "masking_char": "*",
@@ -18,7 +20,7 @@ OPERATOR_EXAMPLE1_STR = json.dumps(OPERATOR_EXAMPLE1, indent=2)
 
 OPERATOR_EXAMPLE2 = {
     "type": "replace",
-    "new_value": "<ANONYMIZED>"
+    "new_value": "_ANONYMIZED_"
 }
 OPERATOR_EXAMPLE2_STR = json.dumps(OPERATOR_EXAMPLE2, indent=2)
 
@@ -36,10 +38,17 @@ CUSTOM_OPERATORS = {
     "identity": lambda x: x,
 }
 
+OPERATOR_FAKER = {
+    "type": "faker",
+    "provider": "name",
+    "locale": "fr_FR"
+}
+OPERATOR_FAKER_STR = json.dumps(OPERATOR_FAKER, indent=2)
+
 
 class PseudonimizerParameters(ProcessorParameters):
     mapping: Dict[str, str] = Field(None,
-                                    description="List of anonymization/pseudonymization [operators](https://microsoft.github.io/presidio/tutorial/10_simple_anonymization/) like this ones:<br/><li>```" + OPERATOR_EXAMPLE1_STR + "```<li>" + OPERATOR_EXAMPLE2_STR + "```",
+                                    description="List of anonymization/pseudonymization [operators](https://microsoft.github.io/presidio/tutorial/10_simple_anonymization/) like this ones:<br/><li>```" + OPERATOR_EXAMPLE1_STR + "```<li>```" + OPERATOR_EXAMPLE2_STR + "```<li>```" + OPERATOR_FAKER_STR + "```",
                                     extra="key:label,val:json")
     default_operator: str = Field(OPERATOR_LABEL_STR,
                                   description="""Default anonymization/pseudonymization operator to use if no explicit mapping is provided""",
@@ -68,6 +77,11 @@ def operator_from_definition(a, definition):
         replacement = f"<{a.label or a.labelName}>"
         return OperatorConfig("replace",
                               {"new_value": replacement})
+    elif type == "faker":
+        definition.pop("type")
+        provider = definition.pop("provider")
+        fakerop = FakerOp(provider, **definition)
+        return OperatorConfig("custom", {"lambda": fakerop.evaluate})
     elif type in CUSTOM_OPERATORS:
         return OperatorConfig("custom", {"lambda": CUSTOM_OPERATORS[type]})
     else:
@@ -84,7 +98,7 @@ class PseudonimizerProcessor(ProcessorBase):
         mapping = frozenset(params.mapping.items()) if params.mapping else None
         definitions = get_definitions(mapping, params.default_operator)
         engine = get_engine()
-        operators : Dict[str, OperatorConfig] = {}
+        operators: Dict[str, OperatorConfig] = {}
         try:
             for document in documents:
                 if document.annotations:
