@@ -22,12 +22,28 @@ def test_normalize():
         options = PseudonimizerParameters()
         options.mapping = {
             'wikidata': OPERATOR_IDENTITY_STR,
-            'afporganization': json.dumps({
+            'organization': json.dumps({
                 "type": "mask",
                 "masking_char": "X",
                 "chars_to_mask": 3,
                 "from_end": False,
-            })
+            }),
+            'afporganization': json.dumps({
+                "type": "faker",
+                "provider": "company",
+                "locale": "en_US"
+            }),
+            'person': json.dumps({
+                "type": "faker",
+                "provider": "name",
+                "locale": "fr_FR"
+            }),
+            'afpperson': json.dumps({
+                "type": "faker",
+                "provider": "name",
+                "locale": "fr_FR"
+            }
+            )
         }
         anonymizeds = formatter.process([doc], options)
         norm_file = testdir / "data/afp_ner_fr-document-test-anon.json"
